==> kubernetes-model-extensions-4.10.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetUpdateStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DaemonSetUpdateStrategyFluent<A extends DaemonSetUpdateStrategyFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateDaemonSet getRollingUpdate();
    public RollingUpdateDaemonSet buildRollingUpdate();
    public A withRollingUpdate(RollingUpdateDaemonSet rollingUpdate);
    public Boolean hasRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDaemonSet item);
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDaemonSet item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollingUpdateDaemonSetFluent<DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>>{

        
    public N and();    public N endRollingUpdate();
}


}

==> kubernetes-model-extensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/extensions/DaemonSetUpdateStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DaemonSetUpdateStrategyFluent<A extends DaemonSetUpdateStrategyFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateDaemonSet getRollingUpdate();
    public RollingUpdateDaemonSet buildRollingUpdate();
    public A withRollingUpdate(RollingUpdateDaemonSet rollingUpdate);
    public Boolean hasRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateDaemonSet item);
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate();
    public DaemonSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateDaemonSet item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public interface RollingUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RollingUpdateDaemonSetFluent<DaemonSetUpdateStrategyFluent.RollingUpdateNested<N>> {

            public N and();
            public N endRollingUpdate();    }


}
